NetAna About

Version 3.1.7

NetAna uses matrix algebra to solve a set of linear equations in order to solve electronic circuit problems. See the program 'Help Menu' (Help->Doc) or depress the "F1" key for the program documentation also see the examples in the "examples" folder. This program is released under the GNU General Public License version 3 - GPLv3.

See http://www.gnu.org/licenses/#GPL for more information.

Author: James Bainter, Copyright © 2011-2017